==> org.robokind.api.messaging-0.8.6-sources.jar: org/robokind/api/messaging/services/RemoteServiceClient.java <==
/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.api.messaging.services;

import org.robokind.api.common.playable.Playable;
import org.robokind.api.messaging.MessageAsyncReceiver;
import org.robokind.api.messaging.MessageSender;

/**
 * RemoteServiceClient is an interface for controlling a Service through Messaging.
 * RemoteServiceClient extends Playable, offering methods to start, pause, resume, 
 * and stop the service.
 * 
 * @author Matthew Stevenson <www.robokind.org>
 * @param <Config> type of configuration used to initialize the Service.
 */
public interface RemoteServiceClient<Config> extends Playable{
    /**
     * Initializes the Service with the given config.
     * @param config the configuration object used to initialize the Service
     * @throws Exception if there is an error initializing
     */
    public void initialize(Config config) throws Exception;
    
    public void setCommandSender(MessageSender<ServiceCommand> sender);
    
    public void setConfigSender(MessageSender<Config> sender);
    
    public void setErrorReceiver(MessageAsyncReceiver<ServiceError> receiver);
    
    public void setCommandFactory(ServiceCommandFactory factory);
    
    public String getClientId();
    
    public String getHostId();
}

==> org.robokind.api.messaging-0.9.5-sources.jar: org/robokind/api/messaging/services/RemoteServiceClient.java <==
/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.robokind.api.messaging.services;

import org.jflux.api.messaging.rk.MessageAsyncReceiver;
import org.jflux.api.messaging.rk.MessageSender;
import org.robokind.api.common.playable.Playable;

/**
 * RemoteServiceClient is an interface for controlling a Service through Messaging.
 * RemoteServiceClient extends Playable, offering methods to start, pause, resume, 
 * and stop the service.
 * 
 * @author Matthew Stevenson <www.robokind.org>
 * @param <Config> type of configuration used to initialize the Service.
 */
public interface RemoteServiceClient<Config> extends Playable{
    /**
     * Initializes the Service with the given config.
     * @param config the configuration object used to initialize the Service
     * @throws Exception if there is an error initializing
     */
    public void initialize(Config config) throws Exception;
    
    public void setCommandSender(MessageSender<ServiceCommand> sender);
    
    public void setConfigSender(MessageSender<Config> sender);
    
    public void setErrorReceiver(MessageAsyncReceiver<ServiceError> receiver);
    
    public void setCommandFactory(ServiceCommandFactory factory);
    
    public String getClientId();
    
    public String getHostId();
}
